@@ -1,6 +1,6 @@
 import copy
 import numbers
-from abc import ABCMeta, abstractproperty, abstractmethod
+from abc import ABCMeta, abstractmethod
 
 import six
 
@@ -39,6 +39,7 @@ class QueryVariable(object):
 
     Args:
         variable_name (str): Name of variable in query.
+
     """
 
     def __init__(self, variable_name):
@@ -48,13 +49,11 @@ class QueryVariable(object):
     @property
     def name(self):
         """Name used in field filter."""
-
         return self._name
 
     @property
     def variable_name(self):
         """Name of variable in query definition."""
-
         return self._variable_name
 
     def __hash__(self):
@@ -75,8 +74,8 @@ class GraphQlQuery:
 
     Args:
         name (str): Name of query.
+        
     """
-
     offset = 2
 
     def __init__(self, name):
@@ -91,8 +90,8 @@ class GraphQlQuery:
 
         Returns:
             int: Ident spaces.
-        """
 
+        """
         return 0
 
     @property
@@ -101,8 +100,8 @@ class GraphQlQuery:
 
         Returns:
             int: Ident spaces for children.
-        """
 
+        """
         return self.indent
 
     @property
@@ -113,8 +112,8 @@ class GraphQlQuery:
 
         Returns:
             bool: If still need query from server.
-        """
 
+        """
         for child in self._children:
             if child.need_query:
                 return True
@@ -146,8 +145,8 @@ class GraphQlQuery:
 
         Raises:
             KeyError: If variable was already added before.
-        """
 
+        """
         if key in self._variables:
             raise KeyError(
                 "Variable \"{}\" was already set with type {}.".format(
@@ -171,8 +170,8 @@ class GraphQlQuery:
 
         Returns:
             QueryVariable: Variable object used in query string.
-        """
 
+        """
         return self._variables[key]["variable"]
 
     def get_variable_value(self, key, default=None):
@@ -184,8 +183,8 @@ class GraphQlQuery:
 
         Returns:
             Any: Variable value.
-        """
 
+        """
         variable_item = self._variables.get(key)
         if variable_item:
             return variable_item["value"]
@@ -199,9 +198,17 @@ class GraphQlQuery:
             value (Any): Variable value used in query. Variable is not used
                 if value is 'None'.
         """
-
         self._variables[key]["value"] = value
 
+    def get_variable_keys(self):
+        """Get all variable keys.
+
+        Returns:
+            set[str]: Variable keys.
+
+        """
+        return set(self._variables.keys())
+
     def get_variables_values(self):
         """Calculate variable values used that should be used in query.
 
@@ -209,8 +216,8 @@ class GraphQlQuery:
 
         Returns:
             Dict[str, Any]: Variable values by their name.
-        """
 
+        """
         output = {}
         for key, item in self._variables.items():
             value = item["value"]
@@ -224,29 +231,39 @@ class GraphQlQuery:
 
         Args:
             field (BaseGraphQlQueryField): Add field to query children.
-        """
 
+        """
         if field in self._children:
             return
 
         self._children.append(field)
         field.set_parent(self)
 
-    def add_field(self, name, has_edges=None):
+    def add_field_with_edges(self, name):
+        """Add field with edges to query.
+
+        Args:
+            name (str): Field name e.g. 'tasks'.
+
+        Returns:
+            GraphQlQueryEdgeField: Created field object.
+
+        """
+        item = GraphQlQueryEdgeField(name, self)
+        self.add_obj_field(item)
+        return item
+
+    def add_field(self, name):
         """Add field to query.
 
         Args:
             name (str): Field name e.g. 'id'.
-            has_edges (bool): Field has edges so it need paging.
 
         Returns:
-            BaseGraphQlQueryField: Created field object.
-        """
+            GraphQlQueryField: Created field object.
 
-        if has_edges:
-            item = GraphQlQueryEdgeField(name, self)
-        else:
-            item = GraphQlQueryField(name, self)
+        """
+        item = GraphQlQueryField(name, self)
         self.add_obj_field(item)
         return item
 
@@ -258,8 +275,8 @@ class GraphQlQuery:
 
         Raises:
             ValueError: Query has no fiels.
-        """
 
+        """
         if not self._children:
             raise ValueError("Missing fields to query")
 
@@ -294,8 +311,9 @@ class GraphQlQuery:
         Args:
             data (Dict[str, Any]): Data received using calculated query.
             output (Dict[str, Any]): Where parsed data are stored.
-        """
+            progress_data (Dict[str, Any]): Data used for paging.
 
+        """
         if not data:
             return
 
@@ -310,8 +328,8 @@ class GraphQlQuery:
 
         Returns:
             Dict[str, Any]: Parsed output from GraphQl query.
-        """
 
+        """
         progress_data = {}
         output = {}
         while self.need_query:
@@ -335,8 +353,8 @@ class GraphQlQuery:
 
         Returns:
             Dict[str, Any]: Parsed output from GraphQl query.
-        """
 
+        """
         progress_data = {}
         if self.has_multiple_edge_fields:
             output = {}
@@ -376,9 +394,8 @@ class BaseGraphQlQueryField(object):
         name (str): Name of field.
         parent (Union[BaseGraphQlQueryField, GraphQlQuery]): Parent object of a
             field.
-        has_edges (bool): Field has edges and should handle paging.
-    """
 
+    """
     def __init__(self, name, parent):
         if isinstance(parent, GraphQlQuery):
             query_item = parent
@@ -401,6 +418,36 @@ class BaseGraphQlQueryField(object):
     def __repr__(self):
         return "<{} {}>".format(self.__class__.__name__, self.path)
 
+    def add_variable(self, key, value_type, value=None):
+        """Add variable to query.
+
+        Args:
+            key (str): Variable name.
+            value_type (str): Type of expected value in variables. This is
+                graphql type e.g. "[String!]", "Int", "Boolean", etc.
+            value (Any): Default value for variable. Can be changed later.
+
+        Returns:
+            QueryVariable: Created variable object.
+
+        Raises:
+            KeyError: If variable was already added before.
+
+        """
+        return self._parent.add_variable(key, value_type, value)
+
+    def get_variable(self, key):
+        """Variable object.
+
+        Args:
+            key (str): Variable name added to headers.
+
+        Returns:
+            QueryVariable: Variable object used in query string.
+
+        """
+        return self._parent.get_variable(key)
+
     @property
     def need_query(self):
         """Still need query from server.
@@ -409,16 +456,26 @@ class BaseGraphQlQueryField(object):
 
         Returns:
             bool: If still need query from server.
-        """
 
+        """
         if self._need_query:
             return True
 
-        for child in self._children:
+        for child in self._children_iter():
             if child.need_query:
                 return True
         return False
 
+    def _children_iter(self):
+        """Iterate over all children fields of object.
+
+        Returns:
+            Iterator[BaseGraphQlQueryField]: Children fields.
+
+        """
+        for child in self._children:
+            yield child
+
     def sum_edge_fields(self, max_limit=None):
         """Check how many edge fields query has.
 
@@ -431,13 +488,13 @@ class BaseGraphQlQueryField(object):
 
         Returns:
             int: Counter edge fields
-        """
 
+        """
         counter = 0
         if isinstance(self, GraphQlQueryEdgeField):
             counter = 1
 
-        for child in self._children:
+        for child in self._children_iter():
             counter += child.sum_edge_fields(max_limit)
             if max_limit is not None and counter >= max_limit:
                 break
@@ -451,7 +508,8 @@ class BaseGraphQlQueryField(object):
     def indent(self):
         return self._parent.child_indent + self.offset
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def child_indent(self):
         pass
 
@@ -459,13 +517,14 @@ class BaseGraphQlQueryField(object):
     def query_item(self):
         return self._query_item
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def has_edges(self):
         pass
 
     @property
     def child_has_edges(self):
-        for child in self._children:
+        for child in self._children_iter():
             if child.has_edges or child.child_has_edges:
                 return True
         return False
@@ -476,8 +535,8 @@ class BaseGraphQlQueryField(object):
 
         Returns:
             str: Field path in query.
-        """
 
+        """
         if self._path is None:
             if isinstance(self._parent, GraphQlQuery):
                 path = self._name
@@ -487,7 +546,7 @@ class BaseGraphQlQueryField(object):
         return self._path
 
     def reset_cursor(self):
-        for child in self._children:
+        for child in self._children_iter():
             child.reset_cursor()
 
     def get_variable_value(self, *args, **kwargs):
@@ -518,11 +577,13 @@ class BaseGraphQlQueryField(object):
         self._children.append(field)
         field.set_parent(self)
 
-    def add_field(self, name, has_edges=None):
-        if has_edges:
-            item = GraphQlQueryEdgeField(name, self)
-        else:
-            item = GraphQlQueryField(name, self)
+    def add_field_with_edges(self, name):
+        item = GraphQlQueryEdgeField(name, self)
+        self.add_obj_field(item)
+        return item
+
+    def add_field(self, name):
+        item = GraphQlQueryField(name, self)
         self.add_obj_field(item)
         return item
 
@@ -556,8 +617,8 @@ class BaseGraphQlQueryField(object):
 
         Returns:
             Dict[str, Any]: Fields filters.
-        """
 
+        """
         return copy.deepcopy(self._filters)
 
     def _filters_to_string(self):
@@ -579,8 +640,7 @@ class BaseGraphQlQueryField(object):
 
     def _fake_children_parse(self):
         """Mark children as they don't need query."""
-
-        for child in self._children:
+        for child in self._children_iter():
             child.parse_result({}, {}, {})
 
     @abstractmethod
@@ -673,12 +733,38 @@ class GraphQlQueryEdgeField(BaseGraphQlQueryField):
     def __init__(self, *args, **kwargs):
         super(GraphQlQueryEdgeField, self).__init__(*args, **kwargs)
         self._cursor = None
+        self._edge_children = []
 
     @property
     def child_indent(self):
         offset = self.offset * 2
         return self.indent + offset
 
+    def _children_iter(self):
+        for child in super(GraphQlQueryEdgeField, self)._children_iter():
+            yield child
+
+        for child in self._edge_children:
+            yield child
+
+    def add_obj_field(self, field):
+        if field in self._edge_children:
+            return
+
+        super(GraphQlQueryEdgeField, self).add_obj_field(field)
+
+    def add_obj_edge_field(self, field):
+        if field in self._edge_children or field in self._children:
+            return
+
+        self._edge_children.append(field)
+        field.set_parent(self)
+
+    def add_edge_field(self, name):
+        item = GraphQlQueryField(name, self)
+        self.add_obj_edge_field(item)
+        return item
+
     def reset_cursor(self):
         # Reset cursor only for edges
         self._cursor = None
@@ -733,6 +819,9 @@ class GraphQlQueryEdgeField(BaseGraphQlQueryField):
                     nodes_by_cursor[edge_cursor] = edge_value
                     node_values.append(edge_value)
 
+            for child in self._edge_children:
+                child.parse_result(edge, edge_value, progress_data)
+
             for child in self._children:
                 child.parse_result(edge["node"], edge_value, progress_data)
 
@@ -740,12 +829,12 @@ class GraphQlQueryEdgeField(BaseGraphQlQueryField):
             return
 
         change_cursor = True
-        for child in self._children:
+        for child in self._children_iter():
             if child.need_query:
                 change_cursor = False
 
         if change_cursor:
-            for child in self._children:
+            for child in self._children_iter():
                 child.reset_cursor()
             self._cursor = new_cursor
 
@@ -761,7 +850,7 @@ class GraphQlQueryEdgeField(BaseGraphQlQueryField):
         return filters
 
     def calculate_query(self):
-        if not self._children:
+        if not self._children and not self._edge_children:
             raise ValueError("Missing child definitions for edges {}".format(
                 self.path
             ))
@@ -779,16 +868,21 @@ class GraphQlQueryEdgeField(BaseGraphQlQueryField):
         edges_offset = offset + self.offset * " "
         node_offset = edges_offset + self.offset * " "
         output.append(edges_offset + "edges {")
-        output.append(node_offset + "node {")
+        for field in self._edge_children:
+            output.append(field.calculate_query())
 
-        for field in self._children:
-            output.append(
-                field.calculate_query()
-            )
+        if self._children:
+            output.append(node_offset + "node {")
+
+            for field in self._children:
+                output.append(
+                    field.calculate_query()
+                )
+
+            output.append(node_offset + "}")
+            if self.child_has_edges:
+                output.append(node_offset + "cursor")
 
-        output.append(node_offset + "}")
-        if self.child_has_edges:
-            output.append(node_offset + "cursor")
         output.append(edges_offset + "}")
 
         # Add page information
